==> gtkmathview_0.6.4.orig.tar.gz: gtkmathview-0.6.4/src/formatter/boxml_graphic_device/BoxGraphicDevice.cc <==
// Copyright (C) 2000-2004, Luca Padovani <luca.padovani@cs.unibo.it>.
//
// This file is part of GtkMathView, a Gtk widget for MathML.
// 
// GtkMathView is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// GtkMathView is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with GtkMathView; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// For details, see the GtkMathView World-Wide-Web page,
// http://helm.cs.unibo.it/mml-widget/, or send a mail to
// <lpadovan@cs.unibo.it>

#include <config.h>

#include <cassert>

#include "BoxGraphicDevice.hh"
#include "BoxFormattingContext.hh"
#include "BoxMLElement.hh"
#include "AreaFactory.hh"

BoxGraphicDevice::BoxGraphicDevice()
{ }

BoxGraphicDevice::~BoxGraphicDevice()
{ }

scaled
BoxGraphicDevice::evaluate(const BoxFormattingContext& context,
			   const Length& length, const scaled& defaultValue) const
{
  switch (length.type)
    {
    case Length::UNDEFINED_UNIT:
      return defaultValue;
    case Length::PURE_UNIT:
      // error?
      return defaultValue * length.value;
    case Length::INFINITY_UNIT:
      return scaled::max();
    case Length::LT_UNIT:
      return defaultLineThickness(context) * length.value;
    case Length::EM_UNIT:
      return em(context) * length.value;
    case Length::EX_UNIT:
      return ex(context) * length.value;
    case Length::PX_UNIT:
      return scaled((72.27 * length.value) / dpi(context));
    case Length::IN_UNIT:
      return scaled(72.27 * length.value);
    case Length::CM_UNIT:
      return scaled(72.27 * (length.value / 2.54));
    case Length::MM_UNIT:
      return scaled(72.27 * (length.value / 254.0));
    case Length::PT_UNIT:
      return scaled(length.value);
    case Length::PC_UNIT:
      return scaled(12 * 72.27 * length.value);
    case Length::PERCENTAGE_UNIT:
      return (defaultValue * length.value) / 100.0;
    default:
      assert(false);
      return defaultValue;
    }
}

double
BoxGraphicDevice::dpi(const BoxFormattingContext&) const
{
  return 72.0;
}

scaled
BoxGraphicDevice::em(const BoxFormattingContext& context) const
{
  return context.getSize();
}

scaled
BoxGraphicDevice::ex(const BoxFormattingContext& context) const
{
  return string(context, "x", scaled::min())->box().height;
}

scaled
BoxGraphicDevice::defaultLineThickness(const BoxFormattingContext& context) const
{
  // at least 1px thick
  return std::max(context.getSize() / 10, scaled(72.27 / dpi(context)));
}

AreaRef
BoxGraphicDevice::wrapper(const BoxFormattingContext&, const AreaRef& area) const
{
  return area;
}

AreaRef
BoxGraphicDevice::dummy(const BoxFormattingContext&) const
{
  //assert(false);
  return getFactory()->horizontalSpace(scaled::zero());
}

==> gtkmathview_0.6.5.orig.tar.gz: gtkmathview-0.6.5/src/formatter/boxml_graphic_device/BoxGraphicDevice.cc <==
// Copyright (C) 2000-2004, Luca Padovani <luca.padovani@cs.unibo.it>.
//
// This file is part of GtkMathView, a Gtk widget for MathML.
// 
// GtkMathView is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// GtkMathView is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with GtkMathView; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// For details, see the GtkMathView World-Wide-Web page,
// http://helm.cs.unibo.it/mml-widget/, or send a mail to
// <lpadovan@cs.unibo.it>

#include <config.h>

#include <cassert>

#include "BoxGraphicDevice.hh"
#include "FormattingContext.hh"
#include "BoxMLElement.hh"
#include "AreaFactory.hh"

BoxGraphicDevice::BoxGraphicDevice()
{ }

BoxGraphicDevice::~BoxGraphicDevice()
{ }

scaled
BoxGraphicDevice::ex(const FormattingContext& context) const
{
  return string(context, "x", scaled::min())->box().height;
}

AreaRef
BoxGraphicDevice::wrapper(const FormattingContext&, const AreaRef& area) const
{
  return area;
}

AreaRef
BoxGraphicDevice::dummy(const FormattingContext&) const
{
  //assert(false);
  return getFactory()->horizontalSpace(scaled::zero());
}
